/*
 * fsm.h
 * Interface to the Node finite state machine.
 *
 * Copyright (C) Leni Mayo 2001-2002
 *
 *	This program is free software; you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License, version 2, as
 *	published by the Free Software Foundation.
 *	
 *	This program is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU General Public License for more details.
 *	
 *	You should have received a copy of the GNU General Public License
 *	along with this program; if not, write to the Free Software
 *	Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
/*
 * Overview
 *
 * The fsm models the life-cycle of service names, managed internally as Nodes
 * in the directed graph.
 *
 *                      --------------
 *                      | REGISTER   |
 *                      | FAILED     |
 *   Initial            |------------|                                    
 *   State                / \     |                                        
 *     |          process  |      |  register
 *     |          failure  |      |                                        
 *    \ /                  |     \ /                  deregister              
 *  -----------         |-------------         ------ ------> ---------------
 *  | SPIRIT  |         | ONTHEWAYIN |         | IN |         | ONTHEWAYOUT |
 *  ----------- ------> |------------| ------> ------ <------ ---------------
 *     / \      register               process         process    | 
 *      |                              success         failure    | process   
 *      |                                                         | success
 *      -----------------------------------------------------------
 *
 *	Labels in upper case are states
 *  Labels in lower case are events
 */
#ifndef _FSM_H_
#define _FSM_H_

#include "common.h"

typedef enum
{
	eStateSpirit,   /* Initial State */
	eStateOnTheWayIn,
	eStateRegisterFailed,
	eStateIn,
	eStateOnTheWayOut,
} State;

typedef enum
{
	eEventRegister,
	eEventProcessSuccess,
	eEventProcessFailure,
	eEventDeregister,
} Event;

extern int fsmStateNext(State *pNext, State current, Event event);
extern const char *stateAsString(State state);

#endif /* _FSM_H_ */
